var indexSectionsWithContent =
{
  0: ":_abcdefghijklmnopqrstuvwxyz~",
  1: "abcdefghijklmnopqrstuvw",
  2: "opt",
  3: "abcdefgilmnopqrstuv",
  4: "abcdefghijklmnopqrstuvwxyz~",
  5: "abcdfghilmnoprstvwxyz",
  6: "_abcdefghilmnopqrstuvwxz",
  7: "abcdfglmnrstv",
  8: "abcdefghilmnoprstuvwxyz",
  9: ":abcfilmoprstv",
  10: "ceopuv",
  11: "cdfoprtu"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related",
  10: "defines",
  11: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends",
  10: "Macros",
  11: "Pages"
};

